@@ -119,29 +119,31 @@ class TransformDGP(BaseDataGenusProcessor):
             auto_mdy=dict(ignoretz=True, dayfirst=False, yearfirst=False),
         )
 
+        def process_row(row, parsers):
+            for name, parser_info in parsers:
+                if row.get(name):
+                    try:
+                        row[name] = dateutil_parse(row[name], **parser_info)
+                    except ValueError:
+                        pass
+            return row
+
         def func(package: PackageWrapper):
             parsers = []
             for resource in package.pkg.descriptor['resources']:
                 if resource['name'] != RESOURCE_NAME:
                     continue
                 for field in resource['schema']['fields']:
-                    if field['type'] == 'datetime':
+                    if field['type'] in ('datetime', 'date'):
                         if field['format'] in auto_transforms:
                             parsers.append((field['name'], auto_transforms[field['format']]))
                             field['format'] = 'default'
             yield package.pkg
             for res in package:
                 if res.res.name != RESOURCE_NAME or len(parsers) == 0:
-                    yield from res
+                    yield res
                 else:
-                    for row in res:
-                        for name, parser_info in parsers:
-                            if row.get(name):
-                                try:
-                                    row[name] = dateutil_parse(row[name], **parser_info)
-                                except ValueError:
-                                    pass
-                        yield row
+                    yield (process_row(row, parsers) for row in res)
         return func
 
     def flow(self):
